/*
 * Copyright 2016 (c) Anna Schumaker.
 */
#include <core/playlists/type.h>


/*
 * Noop playlist operations.
 */
void playlist_noop_set_flag(struct playlist *playlist,
			    enum queue_flags flag, bool enabled)
{
}

void playlist_noop_sort(struct playlist *playlist,
			enum compare_t sort, bool reset)
{
}


/*
 * Generic playlist operations.
 */
void playlist_generic_init(struct playlist *playlist, unsigned int flags,
			   struct queue_ops *ops)
{
	queue_init(&playlist->pl_queue, flags | Q_ENABLED, ops, playlist);
	queue_sort(&playlist->pl_queue, COMPARE_ARTIST, true);
	queue_sort(&playlist->pl_queue, COMPARE_YEAR,   false);
	queue_sort(&playlist->pl_queue, COMPARE_TRACK,  false);
}

bool playlist_generic_add_track(struct playlist *playlist, struct track *track)
{
	if (queue_has(&playlist->pl_queue, track))
		return false;
	queue_add(&playlist->pl_queue, track);
	return true;
}

bool playlist_generic_remove_track(struct playlist *playlist, struct track *track)
{
	return queue_remove_all(&playlist->pl_queue, track);
}

void playlist_generic_set_flag(struct playlist *playlist,
			       enum queue_flags flag, bool enabled)
{
	if (enabled)
		return queue_set_flag(&playlist->pl_queue, flag);
	return queue_unset_flag(&playlist->pl_queue, flag);
}

void playlist_generic_sort(struct playlist *playlist,
			   enum compare_t sort, bool reset)
{
	queue_sort(&playlist->pl_queue, sort, reset);
}
